/*
 * vl53l0x_i2c_comms.c
 *
 * Created: 11.04.2018 08:28:47
  */ 

#include "vl53l0x_i2c_platform.h"
#include "vl53l0x_def.h"
#include "i2cmaster.h"

int32_t VL53L0X_write_multi(uint8_t address, uint8_t index, uint8_t  *pdata, int32_t count)
{
	i2c_start_wait((address << 1) + I2C_WRITE);
	i2c_write(index);
	
	while(count--)	
	{
		i2c_write((uint8_t)pdata[0]);
		pdata++;
	}
	
	i2c_stop();
	
	return VL53L0X_ERROR_NONE;
}

int32_t VL53L0X_read_multi(uint8_t address,  uint8_t index, uint8_t  *pdata, int32_t count)
{
	i2c_start_wait((address << 1) + I2C_WRITE);
	i2c_write(index);
	i2c_stop();
	
	i2c_rep_start((address << 1) + I2C_READ);
	
	while(count--)
	{
		if (count > 0)
			pdata[0] = i2c_readAck();
		else
			pdata[0] = i2c_readNak();
		
		pdata++;
	}
	
	i2c_stop();
	
	return VL53L0X_ERROR_NONE;
}

int32_t VL53L0X_write_byte(uint8_t address,  uint8_t index, uint8_t   data)
{
	return VL53L0X_write_multi(address, index, &data, 1);
}

int32_t VL53L0X_write_word(uint8_t address,  uint8_t index, uint16_t  data)
{
	uint8_t buff[2];
	buff[0] = (uint8_t)(data >> 8);
	buff[1] = (uint8_t)(data & 0xFF);
	
	return VL53L0X_write_multi(address, index, buff, sizeof(buff));
}

int32_t VL53L0X_write_dword(uint8_t address, uint8_t index, uint32_t  data)
{
	uint8_t buff[4];
	buff[0] = (uint8_t)(data >> 24);
	buff[1] = (uint8_t)(data >> 16);
	buff[2] = (uint8_t)(data >> 8);
	buff[3] = (uint8_t)(data & 0xFF);
	
	return VL53L0X_write_multi(address, index, buff, sizeof(buff));	
}

int32_t VL53L0X_read_byte(uint8_t address,  uint8_t index, uint8_t  *pdata)
{
	return VL53L0X_read_multi(address, index, pdata, 1);
}

int32_t VL53L0X_read_word(uint8_t address,  uint8_t index, uint16_t *pdata)
{
	uint8_t buff[2];
	
	int r = VL53L0X_read_multi(address, index, buff, 2);
	
	uint16_t tmp;
	tmp = buff[0];
	tmp <<= 8;
	tmp |= buff[1];
	
	*pdata = tmp;

	return r;	
}

int32_t VL53L0X_read_dword(uint8_t address, uint8_t index, uint32_t *pdata)
{
  uint8_t buff[4];
  int r = VL53L0X_read_multi(address, index, buff, 4);

  uint32_t tmp;
  tmp = buff[0];
  tmp <<= 8;
  tmp |= buff[1];
  tmp <<= 8;
  tmp |= buff[2];
  tmp <<= 8;
  tmp |= buff[3];

  *pdata = tmp;

  return r;	
}
